"""
Created on 20.04.2021

@author: baier
"""
import pandas as pd
import os
from dotenv import load_dotenv
from accessOutlookEmail import create_account, send_email, save_attachment

load_dotenv()


def edit_save_report(save_to_folder: str, account):
    # open Excel
    os.chdir(save_to_folder)
    df = pd.read_excel(save_attachment('JoinITReport', r'U:\baier.ORCA\Attachments', account))
    
    # edit the file
    new_header = df.iloc[1] 
    df = df[2:] 
    df.columns = new_header
    df = df.reset_index(drop=True)
    rows = df[df.columns[0]].count()
    col_c = df['ISIN']
    for isin in range(rows):
        if col_c[isin][:2] != "JP":
            df = df.drop([isin])
            
    # change width of columns
    writer = pd.ExcelWriter(r"U:\baier.ORCA\Attachments\reportJP.xlsx")
    df.to_excel(writer, sheet_name='report', index=False, na_rep='NaN')
    
    # Auto-adjust columns' width
    for column in df:
        column_width = max(df[column].astype(str).map(len).max(), len(column))
        col_idx = df.columns.get_loc(column)
        writer.sheets['report'].set_column(col_idx, col_idx, column_width)
    
    writer.save()


def main():
    account = create_account(os.getenv('email_robert'), os.getenv('password_robert'))
    edit_save_report(r'U:\baier.ORCA\Attachments', account)

    attachments = []
    os.chdir(r'U:\baier.ORCA\Attachments')
    with open('reportJP.xlsx', 'rb') as f:
        content = f.read()
    attachments.append((r'reportJP.xlsx', content))

    send_email(account, 'JP Common Stocks', 'This is an automated email - do not reply',
               ['kugler@orcacapital.de'], attachments=attachments)
    print('Email was sent to Kugler Christoph')


if __name__ == '__main__':
    main()



from exchangelib import DELEGATE, Account, Credentials


def create_credentials(username: str, password: str):
    credentials = Credentials(
        username=username,
        password=password
    )
    return credentials


def create_account(email_address: str, password: str):
    account = Account(
        primary_smtp_address=email_address,
        credentials=create_credentials(email_address, password),
        autodiscover=True,
        access_type=DELEGATE
    )
    return account



"""
Created on 30.04.2021

@author: baier
"""

from exchangelib import Message, Mailbox, FileAttachment
from exchangelib.properties import HTMLBody


def send_email(account, subject, body, recipients, attachments=None):
    to_recipients = []
    for recipient in recipients:
        to_recipients.append(Mailbox(email_address=recipient))
    # Create message
    m = Message(account=account,
                folder=account.sent,
                subject=subject,
                body=HTMLBody(body),
                to_recipients=to_recipients)

    # attach files
    for attachment_name, attachment_content in attachments or []:
        file = FileAttachment(name=attachment_name, content=attachment_content)
        m.attach(file)

    m.send_and_save()



from setuptools import setup, find_packages

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent


VERSION = '0.1.5'
DESCRIPTION = 'Send/Save Emails & Attachments via Outlook'
LONG_DESCRIPTION = (this_directory / "README.md").read_text()

# Setting up
setup(
    name="access_outlook_email",
    version=VERSION,
    author="Valentin Baier",
    author_email="valentin_baier@gmx.de",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=['exchangelib'],
    keywords=['python', 'email', 'outlook', 'send', 'send email', 'save', 'save email'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



"""
Created on 10.05.2021

@author: baier
"""
import os

from dotenv import load_dotenv
from accessOutlookEmail import create_account, save_attachment

load_dotenv()


def main():
    account = create_account(os.getenv('email_robert'), os.getenv('password_robert'))
    save_attachment('Steubing', r'W:\01. ORCA Depot\Z InputConfirms\Steubing', account)


if __name__ == '__main__':
    main()
